@@ -126,14 +126,16 @@ impl<'de> Visitor<'de> for JsonValue {
     {
         let dict_ptr = ffi!(PyDict_New());
         while let Some(key) = map.next_key::<beef::lean::Cow<str>>()? {
-            let (pykey, pyhash) = get_unicode_key(&key);
+            let pykey = get_unicode_key(&key);
             let pyval = map.next_value_seed(self)?;
-            let _ = ffi!(_PyDict_SetItem_KnownHash(
-                dict_ptr,
-                pykey,
-                pyval.as_ptr(),
-                pyhash
-            ));
+            let _ = unsafe {
+                pyo3_ffi::_PyDict_SetItem_KnownHash(
+                    dict_ptr,
+                    pykey,
+                    pyval.as_ptr(),
+                    str_hash!(pykey),
+                )
+            };
             py_decref_without_destroy!(pykey);
             py_decref_without_destroy!(pyval.as_ptr());
         }
